package test;

import java.rmi.RemoteException;

import www.mymsp.eu.external.ws2.MyMSPInterface1Proxy;
import eu.mymsp.ws2.mymsp.type.jaws.BasicRequest;
import eu.mymsp.ws2.mymsp.type.jaws.MessageContent;
import eu.mymsp.ws2.mymsp.type.jaws.MsgContentRequest;
import eu.mymsp.ws2.mymsp.type.jaws.MsgContentResponse;
import eu.mymsp.ws2.mymsp.type.jaws.ParamsResponse;
import eu.mymsp.ws2.mymsp.type.jaws.ReceivedMessRequest;
import eu.mymsp.ws2.mymsp.type.jaws.ReceivedMessResponse;
import eu.mymsp.ws2.mymsp.type.jaws.Recipient;
import eu.mymsp.ws2.mymsp.type.jaws.SendRequest;
import eu.mymsp.ws2.mymsp.type.jaws.SendResponse;
import eu.mymsp.ws2.mymsp.type.jaws.SendResultRequest;
import eu.mymsp.ws2.mymsp.type.jaws.SendResultResponse;

public class TestApp {
  
  private static long msgNo;
  
  public TestApp() {
    
    // Uncomment methods to test them:
    this.testPing();
    //this.testGetParams();
    //this.testSendMsgSMS();
    //this.testSendMsgMMS();
    //this.testGetSendResult();
    //this.testGetReceivedMessages();
    //this.testGetMsgContent();
  }

  // ------------------------------------------------------------------- Main
  public static void main(String args[]) {
    TestApp app = new TestApp();
  }

  // ------------------------------------------------------- TestCase Methods

  private void testPing() {
    String response = "";
    
    try {
      response = getMyMSP().ping("Godmorgon!");
    }
    catch (RemoteException e) {
      response = e.getLocalizedMessage();
    }
    
    System.out.println(response);
  }

  private void testGetParams() {
    
    BasicRequest request = new BasicRequest();
    
    request.setIdentification(MyMSPUtil.getId());
    
    ParamsResponse response = null;
    
    try {
      response = getMyMSP().getParams(request);
    }
    catch (RemoteException e) {
      e.printStackTrace();
    }

    if (response != null){
      System.out.println(response.getResultCode());
      System.out.println(response.getResultDescription());
    }
  }

  private void testSendMsgSMS() {
    // Create a new send-request
    SendRequest request = new SendRequest();
   
    // Fill the send-request
    request.setRecipients(new Recipient[] {
        MyMSPUtil.getRecipient("46703123456", "0703-123456", "John Doe"),
        MyMSPUtil.getRecipient("46703654321", "0703-654321", "Jane Doe")
        }); 
    request.setIdentification(MyMSPUtil.getId());
    request.setMsgType("SMS");
    request.setOriginatorText("CompanyX");
    request.setSmsText("Test text åäö");
    request.setExternalRef("4321");

    // Create a object to hold the result of the send attempt
    SendResponse response = null;
    
    try {
      // Transmit the send request to myMSP and save the result in the
      // send response-object
      response = getMyMSP().sendMsg(request);
      msgNo = response.getMsgNo();
    }
    catch (RemoteException e) {
      e.printStackTrace();
    }

    if (response != null){
      System.out.println(response.getResultCode());
      System.out.println(response.getResultDescription());
    }
  }

  private void testSendMsgMMS() {
    // Create a new send-request
    SendRequest request = new SendRequest();
    
    // Fill the send-request
    request.setRecipients(new Recipient[] {
        MyMSPUtil.getRecipient("46703123456", "0703-123456", "John Doe"),
        MyMSPUtil.getRecipient("46703654321", "0703-654321", "Jane Doe")
        });
    request.setIdentification(MyMSPUtil.getId());
    request.setMsgType("MMS");
    request.setOriginatorText("CompanyX");
    request.setSubject("Test MMS åäö");
    request.setExternalRef("1234");
    request.setRequestReadReceipt(true);
    String fileName="C:\\anImage.jpg";
    request.setContents(
        new MessageContent[] {MyMSPUtil.getMessageContent(fileName)});
    
    // Create a object to hold the result of the send attempt
    SendResponse response = null;
    
    try {
      // Transmit the send request to myMSP and save the result in the
      // send response-object
      response = getMyMSP().sendMsg(request);
      msgNo = response.getMsgNo();
    }
    catch (RemoteException e) {
      e.printStackTrace();
    }
    
    if (response != null){
      System.out.println(response.getResultCode());
      System.out.println(response.getResultDescription());
    }
  }

  private void testGetSendResult() {
    // Create a new send result-request
    SendResultRequest request = new SendResultRequest();
    
    // Fill the send result-request
    request.setIdentification(MyMSPUtil.getId());
    request.setMsgNo(msgNo>0? msgNo: 3364);
    
    // Create a object to hold the result of the get result attempt      
    SendResultResponse response = null;
    
    try {
      // Transmit the send result-request to myMSP and save the result in
      // the send result response-object
      response = getMyMSP().getSendResult(request);
    }
    catch (RemoteException e) {
      e.printStackTrace();
    }
    
    if (response != null){
      System.out.println(response.getResultCode());
      System.out.println(response.getResultDescription());
    }
  }

  private void testGetReceivedMessages() {
    // Create a new received messages-request
    ReceivedMessRequest request = new ReceivedMessRequest();
    
    // Fill the received message-request
    request.setIdentification(MyMSPUtil.getId());
    request.setLastMsgNo(msgNo>0? msgNo-5: 3364);
    
    // Create a object to hold the result of the get incomming
    // messages attempt  
    ReceivedMessResponse response = null;
    
    try {
      // Transmit the received messages-request to myMSP and save the
      // result in the received messages-object
      response = getMyMSP().getReceivedMessages(request);
    }
    catch (RemoteException e) {
      e.printStackTrace();
    }
    
    if (response != null){
      System.out.println(response.getResultCode());
      System.out.println(response.getResultDescription());
    }
  }

  private void testGetMsgContent() {
    // Create a new message content-request
    MsgContentRequest request = new MsgContentRequest();
    
    // Fill the message content request
    request.setIdentification(MyMSPUtil.getId());
    request.setMsgNo(msgNo>0? msgNo: 3293);
    
    // Create a object to hold the result of the get message
    // content attempt  
    MsgContentResponse response = null;
    
    try {
      // Transmit the message content-request to myMSP and save the
      // result in the message content-object
      response = getMyMSP().getMsgContent(request);
    }
    catch (RemoteException e) {
      e.printStackTrace();
    }
    
    if (response != null){
      System.out.println(response.getResultCode());
      System.out.println(response.getResultDescription());
    }
  }

  // ------------------------------------------------------- Supporting Methods

  private MyMSPInterface1Proxy getMyMSP() {
    MyMSPInterface1Proxy myMSP = new MyMSPInterface1Proxy();
    myMSP.setEndpoint("https://www.mymsp.eu/external/ws2/myMSP");
    
    //Test environment-address:
    //http://85.235.1.102:8089/external/ws2/myMSP
    return myMSP;
  }

}
